# pftk

Python Finance Toolkit [![PyPI version](https://badge.fury.io/py/QSTK.png)](http://badge.fury.io/py/QSTK)

## Website & Documentation

[https://charlesg.github.io/pftk/](https://charlesg.github.io/pftk/)

## Source Repository

[https://github.com/charlesg/pftk](https://github.com/charlesg/pftk.git)

## Dependencies

- numpy >= 1.6.1,
- scipy >= 0.9.0,
- matplotlib >= 1.1.0,
- pandas >= 0.7.3,
- python-dateutil >= 1.5,
- cvxopt >= 1.1.3,
- scikit-learn >= 0.11

### Vagrant Image

Vagrant image with QSTK installed can be found at [https://github.com/Wesseldr/vagrant-QSTK](https://github.com/Wesseldr/vagrant-QSTK)

## Author

- Charles Gagnon - charlesg at unixrealm.com - https://www.unixrealm.com

### Original Authors

- [Prof. Tucker Balch](http://www.cc.gatech.edu/~tucker/)
- [Sourabh Bajaj](http://www.sourabhbajaj.com/)
- [John Cornwell](https://github.com/JWCornV)

Python Finance Toolkit is a fork from QSTK from Professor Tucker Balch. Initial QSTK code at:

* Website & Documentation [wiki.quantsoftware.org](http://wiki.quantsoftware.org)
* Source Repository [https://github.com/QuantSoftware/QuantSoftwareToolkit](https://github.com/QuantSoftware/QuantSoftwareToolkit)

## Contributing

Please read [CONTRIBUTING.md](https://gist.github.com/PurpleBooth/b24679402957c63ec426) for details on our code of conduct, and the process for submitting pull requests to us.

## Versioning

We use [SemVer](http://semver.org/) for versioning. For the versions available, see the [tags on this repository](https://github.com/your/project/tags). 

## License

This project is licensed under the New BSD License - see the [LICENSE.md](LICENSE.md) file for details.

